==> content_model_documentation-1.0.12.tar.gz: content_model_documentation/README.md <==

Content Model Documentation's intent is to surface both the content model and
architecture of a Drupal site. It allows additional documentation of fields,
entities that use them, modules and other site related notes.

## Relevant Paths

* Help README.md [/admin/help/content_model_documentation](/admin/help/content_model_documentation)
* Permissions [/admin/people/permissions/module/content_model_documentation](/admin/people/permissions/module/content_model_documentation)
* Settings [/admin/config/system/content_model_documentation](/admin/config/system/content_model_documentation) -
  The settings to control which entity types are documentable.  Fields can be
  added to Content Model Documents as well.
* Entity Relationship Diagrams [/admin/reports/content-model/entity-diagram](/admin/reports/content-model/entity-diagram)
* Workflow Diagrams [/admin/reports/content-model/workflow/](/admin/reports/content-model/workflow/)
* Content Model Documents [/admin/structure/cm_document](/admin/structure/cm_document)
* Reports [/admin/reports/content-model/](/admin/reports/content-model/)
* Fields reports [/admin/reports/content-model/field-search](/admin/reports/content-model/field-search)

## Features

  * Reports
    * Entity Relationship Diagrams [/admin/reports/content-model/entity-diagram/](/admin/reports/content-model/entity-diagram/) -
    Diagrams that show references from one entity to another.
    * Content Model Fields View [/admin/reports/content-model/fields/](/admin/reports/content-model/fields/) -
    A list of all fields used in the Drupal instance.  Displaying labels,
    description, entity types, bundles, and other information.  This View, once
    the module is installed, can be edited with Views UI to make add or remove
    columns or filters.
    * Field search [/admin/reports/content-model/field-search](/admin/reports/content-model/fields-search) -
    Provide an interface to search through all active fields of your site.
    * Enabled Modules list [/admin/reports/content-model/modules/enabled/](/admin/reports/content-model/modules/enabled/) -
    A list of all enabled modules with links to the project page, the help page
    and a link to existing Content Model Documents for the module.
  * Content Model Documents list [/admin/structure/cm_document](/admin/structure/cm_document) -
    The list of Content Model Documents.  The list is a View that can be
    modified.
  * Workflow States and Transitions Diagrams [/admin/reports/content-model/workflow/](/admin/reports/content-model/workflow/)
    Diagrams show how Workflow States relate to each other by Transition.


## Dependencies

  * Config Views (config_views) is necessary to be able to create the Views of
  configuration entities.  Caution: Config Views enables some of its own Views
  by default that replace some Drupal core list pages.
  * Mermaid JS is required and the minified js file is referenced from a CDN.

==> content_model_documentation-1.0.16.tar.gz: content_model_documentation/README.md <==

Content Model Documentation's intent is to surface both the content model and
architecture of a Drupal site. It allows additional documentation of fields,
entities that use them, modules and other site related notes.

## Relevant Paths

* Help README.md [/admin/help/content_model_documentation](/admin/help/content_model_documentation)
* Permissions [/admin/people/permissions/module/content_model_documentation](/admin/people/permissions/module/content_model_documentation)
* Settings [/admin/config/system/content_model_documentation](/admin/config/system/content_model_documentation) -
  The settings to control which entity types are documentable.  Fields can be
  added to Content Model Documents as well.
* Content Model Documents [/admin/structure/cm_document](/admin/structure/cm_document)
* Content Model Reports [/admin/reports/content-model/](/admin/reports/content-model/)
* System Reports [/admin/reports/system](/admin/reports/system)

## Features

  * System Reports
    * Enabled Modules list [/admin/reports/system/enabled-modules](/admin/reports/system/enabled-modules) -
    A list of all enabled modules with links to the project page, the help page
    and a link to existing Content Model Documents for the module.
    * Workflow States and Transitions Diagrams [/admin/reports/system/workflow](/admin/reports/system/workflow)
      Diagrams show how Workflow States relate to each other by Transition.
  * Content Model Reports
    * Node count report [/admin/reports/content-model/node-count](/admin/reports/content-model/node-count) -
      A listing of all node content types and counts for how many exist.
    * Field search [/admin/reports/content-model/field-search](/admin/reports/content-model/field-search) -
    Provide an interface to search through all active fields of your site.
    * Content Model Fields View [/admin/reports/content-model/fields/](/admin/reports/content-model/fields/) -
    A list of all fields used in the Drupal instance.  Displaying labels,
    description, entity types, bundles, and other information.  This View, once
    the module is installed, can be edited with Views UI to make add or remove
    columns or filters.
    * Entity Relationship Diagrams [/admin/reports/content-model/entity-diagram](/admin/reports/content-model/entity-diagram/) -
    Diagrams that show references from one entity to another.


  * Content Model Documents list [/admin/structure/cm_document](/admin/structure/cm_document) -
    The list of Content Model Documents.  The list is a View that can be
    modified.



## Dependencies

  * Config Views (config_views) is necessary to be able to create the Views of
  configuration entities.  Caution: Config Views enables some of its own Views
  by default that replace some Drupal core list pages.
  * Mermaid JS is required and the minified js file is referenced from a CDN.
